﻿/**
* Simple inline TextField class
* Foundation Flash Applications for Mobile Devices
*/
import mx.utils.Delegate;
 
class InlineTextField extends MovieClip
{
	// alpha numeric keys A-Z etc.
	public static var ALPHA:String = "alpha";

	// numeric keys 0-9
	public static var NUMERIC:String = "numeric";

	// all keys A-Za-z0-9
	public static var ALPHA_NUMERIC:String = "alphaNumeric";

	// character change timeout
	public static var CHAR_CHANGE_TIMEOUT:Number = 1500; // ms
	
	public var inputMode:String = ALPHA_NUMERIC; // default input mode
		
	private var __labelField:TextField;
	private var __arrowMC:MovieClip;
	private var __inputModeMC:MovieClip;
	
	private var __hasFocus:Boolean = false;
	private var __charIndex:Number = 0;
	private var __enteringChar:Boolean = false;
	private var __upperCase:Boolean = false;
	private var __previousKey:String = "";
	private var __deleteKey:Number = Key.LEFT;
	private var __caseKey:Number = 42;	// * key
	private var __timeoutInterval:Number = null;

	// the list of available characters and 
	// how these can be accesed per key
	private var __keys:Object =  {_1:49, _2:50, _3:51, _4:52, _5:53,
								  _6:54, _7:55, _8:56, _9:57, _0:48};
								  
	private var __chars:Object = {_1:[".",",","1"],
								  _2:["a","b","c","2"],
								  _3:["d","e","f","3"],
								  _4:["g","h","i","4"],
								  _5:["j","k","l","5"],
								  _6:["m","n","o","6"],
								  _7:["p","q","r","s","7"],
								  _8:["t","u","v","8"],
								  _9:["w","x","y","z","9"],
								  _0:[" ","_","0"] };
	
	/**
	 *
	 */
	public function set upperCase(toggleUpper:Boolean)
	{
		__upperCase = toggleUpper;
		
		if(__upperCase) __inputModeMC.gotoAndStop("alphaNumericUpper");
		else __inputModeMC.gotoAndStop("alphaNumeric");
	}
	
	/**
	 *
	 */
	public function get upperCase() : Boolean
	{
		return __upperCase;
	}
	
	/**
	 *
	 */
	public function InlineTextField ()
	{
		var kl:Object = new Object();
		kl.onKeyDown = Delegate.create(this, onKeyPress);
		Key.addListener(kl);
	}
	
	
	/**
	 *
	 */
	public function setFocus (toggleFocus:Boolean) : Void
	{
		__hasFocus = toggleFocus;
	}
	
	
	/**
	 *
	 */
	public function setDeleteKey(keyCode:Number) : Void
	{
		__deleteKey = keyCode;
	}
	
	
	/**
	 *
	 */
	public function setCaseKey(keyCode:Number) : Void
	{
		__caseKey = keyCode;
	}
	
	
	/**
	 *
	 */
	private function onKeyPress () : Void
	{
		if(__hasFocus) 
		{
			// Check to see if it is an upper case command
			if(Key.getAscii() == __caseKey)
			{
				upperCase = !upperCase;
			}
			else if(Key.getCode() == __deleteKey)
			{
				__labelField.text = __labelField.text.substr(0, __labelField.text.length-1);
			}
			else
			{
				processInput();
			}
		}
	}
	
	
	/**
	 *
	 */
	private function processInput() : Void
	{
		var str:String = __labelField.text;
		
		for(var key in __keys)
		{				
			if(Key.getCode()==__keys[key])
			{
				if(__enteringChar && (key == __previousKey))
				{
					if(__charIndex < __chars[key].length-1) __charIndex++;
					else __charIndex = 0;
					str = str.substr(0, str.length-1);
				}
				else __charIndex = 0;
				
				clearInterval(__timeoutInterval);
				
				str += (__upperCase) ? __chars[key][__charIndex].toUpperCase() : __chars[key][__charIndex];
				__enteringChar = true;
				__previousKey = key;						
				__timeoutInterval = setInterval(this, "inputTimeout", CHAR_CHANGE_TIMEOUT);
			}
		}
				
		__labelField.text = str;
	}
	
	
	/**
	 *
	 */
	private function inputTimeout() : Void
	{
		__enteringChar = false;
		__arrowMC.play();
		clearInterval(__timeoutInterval);
	}
}